Struct dunge::ActiveLayer

source ·
pub struct ActiveLayer<'l, S, T> { /* private fields */ }
The frame’s active layer.

Can be created from the Frame instance by calling the layer function.

Implementations

source

impl<'l, S, T> ActiveLayer<'l, S, T>

source

pub fn bind_globals(&mut self, globals: &'l Globals<S>) -> &mut Self

Binds the globals.

source

pub fn bind_textures(&mut self, textures: &'l Textures<S>) -> &mut Self

Binds the textures.

source

pub fn bind_lights(&mut self, lights: &'l Lights<S>) -> &mut Self

Binds the light sources.

source

pub fn bind_spaces(&mut self, spaces: &'l Spaces<S>) -> &mut Self

Binds the light spaces.

source

pub fn bind_instance(&mut self, instance: &'l Instance) -> &mut Self

Binds the instance.

source

pub fn bind_default_instance(&mut self) -> &mut Self

Binds the default instance with a position at (0, 0, 0) in world coordinates.

After the layer starts, this instance is bound by default, so there is no need to additionally call this method.

source

pub fn bind_instance_color(&mut self, cols: &'l InstanceColor) -> &mut Selfwhere S: Shader,

Binds the color instance.

Panics

Panics if the shader has no instance colors.

source

pub fn draw(&mut self, mesh: &'l Mesh<S::Vertex, T>)where S: Shader, T: Topology,

Draws the mesh.

Panics
  • If globals is not set but required.
  • If textures is not set but required.
  • If light sources is not set but required.
  • If light spaces is not set but required.
  • If instance color is not set but required.
source

pub fn draw_limited(&mut self, mesh: &'l Mesh<S::Vertex, T>, limit: u32)where S: Shader, T: Topology,

Draws the mesh partially with a limit of drawn elements.

For example, pass the limit value of 2 to draw only two triangles (for a triangular mesh) instead of the entire mesh.

Panics

See draw method.