Struct dunge::ActiveLayer
source · pub struct ActiveLayer<'l, S, T> { /* private fields */ }Expand description
Implementations
sourceimpl<'l, S, T> ActiveLayer<'l, S, T>
impl<'l, S, T> ActiveLayer<'l, S, T>
sourcepub fn bind_globals(&mut self, globals: &'l Globals<S>) -> &mut Self
pub fn bind_globals(&mut self, globals: &'l Globals<S>) -> &mut Self
Binds the globals.
sourcepub fn bind_textures(&mut self, textures: &'l Textures<S>) -> &mut Self
pub fn bind_textures(&mut self, textures: &'l Textures<S>) -> &mut Self
Binds the textures.
sourcepub fn bind_lights(&mut self, lights: &'l Lights<S>) -> &mut Self
pub fn bind_lights(&mut self, lights: &'l Lights<S>) -> &mut Self
Binds the light sources.
sourcepub fn bind_spaces(&mut self, spaces: &'l Spaces<S>) -> &mut Self
pub fn bind_spaces(&mut self, spaces: &'l Spaces<S>) -> &mut Self
Binds the light spaces.
sourcepub fn bind_instance(&mut self, instance: &'l Instance) -> &mut Self
pub fn bind_instance(&mut self, instance: &'l Instance) -> &mut Self
Binds the instance.
sourcepub fn bind_default_instance(&mut self) -> &mut Self
pub fn bind_default_instance(&mut self) -> &mut Self
Binds the default instance with a position at (0, 0, 0) in world coordinates.
After the layer starts, this instance is bound by default, so there is no need to additionally call this method.
sourcepub fn bind_instance_color(&mut self, cols: &'l InstanceColor) -> &mut Selfwhere
S: Shader,
pub fn bind_instance_color(&mut self, cols: &'l InstanceColor) -> &mut Selfwhere S: Shader,